@@ -1,14 +1,14 @@
 package Bitcoin::Crypto::BIP44;
-$Bitcoin::Crypto::BIP44::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::BIP44::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
+use Types::Standard qw(Enum);
+use Types::Common::Numeric qw(PositiveOrZeroInt);
 use Scalar::Util qw(blessed);
-use Mooish::AttributeBuilder -standard;
 
-use Bitcoin::Crypto::Types qw(BIP44Purpose PositiveOrZeroInt Bool Enum);
 use Bitcoin::Crypto::Network;
 use Bitcoin::Crypto::Exception;
 
@@ -19,7 +19,7 @@ sub _get_network_constant
 	my $coin_type = $network->bip44_coin;
 
 	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		'no bip44_coin constant found in network configuration'
+		"no bip44_coin constant found in network configuration"
 	) unless defined $coin_type;
 
 	return $coin_type;
@@ -27,12 +27,8 @@ sub _get_network_constant
 
 use namespace::clean;
 
-has param 'purpose' => (
-	isa => BIP44Purpose,
-	default => 44,
-);
-
-has param 'coin_type' => (
+has 'coin_type' => (
+	is => 'ro',
 	isa => PositiveOrZeroInt,
 	coerce => sub {
 		my ($coin_type) = @_;
@@ -52,33 +48,26 @@ has param 'coin_type' => (
 	},
 );
 
-has param 'account' => (
+has 'account' => (
+	is => 'ro',
 	isa => PositiveOrZeroInt,
-	default => 0,
+	default => sub { 0 },
 );
 
-has param 'change' => (
+has 'change' => (
+	is => 'ro',
 	isa => Enum [1, 0],
-	default => 0,
+	default => sub { 0 },
 );
 
-has param 'index' => (
+has 'index' => (
+	is => 'ro',
 	isa => PositiveOrZeroInt,
-	default => 0,
-);
-
-has param 'get_account' => (
-	isa => Bool,
-	default => !!0,
-);
-
-has param 'get_from_account' => (
-	isa => Bool,
-	default => !!0,
+	required => 1,
 );
 
 use overload
-	q{""} => 'as_string',
+	q{""} => "as_string",
 	fallback => 1;
 
 sub as_string
@@ -87,18 +76,9 @@ sub as_string
 
 	# https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki
 	# m / purpose' / coin_type' / account' / change / address_index
-
-	my $path = sprintf "m/%u'/%u'/%u'",
-		$self->purpose, $self->coin_type, $self->account;
-
-	return $path
-		if $self->get_account;
-
-	$path = 'm'
-		if $self->get_from_account;
-
-	return sprintf "%s/%u/%u",
-		$path, $self->change, $self->index;
+	# purpose is always 44 in bip44
+	return sprintf "m/44'/%u'/%u'/%u/%u",
+		$self->coin_type, $self->account, $self->change, $self->index;
 }
 
 1;
@@ -127,7 +107,7 @@ Bitcoin::Crypto::BIP44 - BIP44 implementation in Perl
 
 =head1 DESCRIPTION
 
-This class is a helper for constructing BIP44-compilant key derivation paths. BIP44 describes the mechanism the HD (Hierarchical Deterministic) wallets use to decide derivation paths for coins. BIP49 and BIP84 are constructed the same way, but used for compat and segwit addresses respectively.
+This class is a helper for constructing BIP44-compilant key derivation paths. BIP44 describes the mechanism the HD (Hierarchical Deterministic) wallets use to decide derivation paths for coins.
 
 Each coin has its own C<coin_type> constant, a list of which is maintained here: L<https://github.com/satoshilabs/slips/blob/master/slip-0044.md>. L<Bitcoin::Crypto::Network> instances hold these constants under the C<bip44_coin> property.
 
@@ -139,12 +119,6 @@ Refer to L<https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki> for d
 
 All of these properties can be fetched using a method with the same name.
 
-=head2 purpose
-
-Purpose contains the BIP document number that you wish to use. Can be either C<44>, C<49> or C<84>.
-
-By default, number C<44> will be used.
-
 =head2 coin_type
 
 Needs to be a non-negative integer number. It should be less than C<2^31> (but will not check for that).
@@ -164,26 +138,11 @@ By default, the value C<0> is used.
 =head2 change
 
 Needs to be a number C<1> (for addresses to be used as change outputs) or C<0> (for addresses that are to be used only internally).
-
 By default, the value C<0> is used.
 
 =head2 index
 
-Needs to be a non-negative integer number. It should be less than C<2^31> (but will not check for that).
-
-By default, the value C<0> is used.
-
-=head2 get_account
-
-If passed C<1>, the resulting derivation path will only go as far as to the account part. L</index> and L</change> values will be ignored. Use this to get extended key for the account.
-
-By default, you will get the full derivation path.
-
-=head2 get_from_account
-
-If passed C<1>, the resulting derivation path will start after the account part. L</purpose>, L</coin_type> and L</account> values will be ignored. Use this to further derive key that was only derived up to the account part.
-
-By default, you will get the full derivation path.
+Required. Needs to be a non-negative integer number. It should be less than C<2^31> (but will not check for that).
 
 =head1 METHODS
 
@@ -222,4 +181,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
