@@ -1,8 +1,8 @@
 package Bitcoin::Crypto::Base58;
-$Bitcoin::Crypto::Base58::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Base58::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Exporter qw(import);
 use Crypt::Misc qw(encode_b58b decode_b58b);
@@ -32,7 +32,7 @@ sub encode_base58
 sub encode_base58check
 {
 	my ($bytes) = @_;
-	my $checksum = pack('a' . $CHECKSUM_SIZE, hash256($bytes));
+	my $checksum = pack("a" . $CHECKSUM_SIZE, hash256($bytes));
 	return encode_base58($bytes . $checksum);
 }
 
@@ -41,7 +41,7 @@ sub decode_base58
 	my ($base58encoded) = @_;
 	my $decoded = decode_b58b($base58encoded);
 	Bitcoin::Crypto::Exception::Base58InputFormat->raise(
-		'illegal characters in base58 string'
+		"illegal characters in base58 string"
 	) unless defined $decoded;
 
 	return $decoded;
@@ -52,7 +52,7 @@ sub verify_checksum
 	my ($decoded) = @_;
 	my $encoded_val = substr $decoded, 0, -$CHECKSUM_SIZE;
 	my $checksum = substr $decoded, -$CHECKSUM_SIZE;
-	return unpack('a' . $CHECKSUM_SIZE, hash256($encoded_val)) eq $checksum;
+	return unpack("a" . $CHECKSUM_SIZE, hash256($encoded_val)) eq $checksum;
 }
 
 sub decode_base58check
@@ -61,7 +61,7 @@ sub decode_base58check
 	my $decoded = decode_base58($base58encoded);
 
 	Bitcoin::Crypto::Exception::Base58InputChecksum->raise(
-		'incorrect base58check checksum'
+		"incorrect base58check checksum"
 	) unless verify_checksum($decoded);
 
 	return substr $decoded, 0, -$CHECKSUM_SIZE;
@@ -72,7 +72,7 @@ sub decode_base58check
 __END__
 =head1 NAME
 
-Bitcoin::Crypto::Base58 - Bitcoin's Base58 helpers
+Bitcoin::Crypto::Base58 - Bitcoin's Base58 helpers in Perl
 
 =head1 SYNOPSIS
 
@@ -84,12 +84,12 @@ Bitcoin::Crypto::Base58 - Bitcoin's Base58 helpers
 		decode_base58check
 	);
 
-	my $b58str = encode_base58check(pack 'A*', 'hello');
+	my $b58str = encode_base58check(pack "A*", "hello");
 	my $bytestr = decode_base58check($b58str);
 
 =head1 DESCRIPTION
 
-Implementation of Base58Check algorithm and alias to CryptX C<encode_b58b> / C<decode_b58b>
+Implementation of Base58Check algorithm and alias to CryptX encode_b58b / decode_b58b
 
 =head1 FUNCTIONS
 
@@ -105,8 +105,8 @@ Encoding takes one argument which is byte string.
 
 Decoding takes base58-encoded string
 
-These two functions are just aliases to L<Crypt::Misc/encode_b58b> and
-L<Crypt::Misc/decode_b58b> with some error checking.
+These two functions are just aliases to I<encode_b58b> and I<decode_b58b> from
+L<Crypt::Misc> with some error checking.
 
 =head2 encode_base58check
 
@@ -135,8 +135,6 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 
 =over 2
 
-=item L<Crypt::Misc>
-
 =item L<Bitcoin::Crypto::Key::Private>
 
 =item L<Bitcoin::Crypto::Key::Public>
@@ -144,4 +142,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
