@@ -1,32 +1,27 @@
 package Bitcoin::Crypto::Bech32;
-$Bitcoin::Crypto::Bech32::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Bech32::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Exporter qw(import);
+use Types::Standard qw(Str);
 
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Helpers qw(verify_bytestring);
 use Bitcoin::Crypto::Segwit qw(validate_program);
-use Bitcoin::Crypto::Types qw(Str);
 
 our @EXPORT_OK = qw(
-	translate_5to8
-	translate_8to5
 	encode_bech32
 	decode_bech32
+	split_bech32
 	encode_segwit
 	decode_segwit
 );
 
-use constant BECH32 => 'bech32';
-use constant BECH32M => 'bech32m';
-
 our %EXPORT_TAGS = (all => [@EXPORT_OK]);
 
 my $CHECKSUM_SIZE = 6;
-my $BECH32M_CONSTANT = 0x2bc830a3;
 
 my @alphabet = qw(
 	q p z r y 9 x 8
@@ -54,7 +49,7 @@ sub polymod
 
 sub hrp_expand
 {
-	my @hrp = split //, shift;
+	my @hrp = split "", shift;
 	my (@part1, @part2);
 	for (@hrp) {
 		my $val = ord;
@@ -68,7 +63,7 @@ sub to_numarr
 {
 	my ($string) = @_;
 
-	return [map { $alphabet_mapped{$_} } split //, $string];
+	return [map { $alphabet_mapped{$_} } split "", $string];
 }
 
 sub create_checksum
@@ -82,129 +77,74 @@ sub create_checksum
 	return $checksum;
 }
 
-sub create_checksum_bech32m
-{
-	my ($hrp, $data) = @_;
-	my $polymod = polymod([@{hrp_expand $hrp}, @{to_numarr $data}, (0) x $CHECKSUM_SIZE]) ^ $BECH32M_CONSTANT;
-	my $checksum;
-	for (0 .. $CHECKSUM_SIZE - 1) {
-		$checksum .= $alphabet[($polymod >> 5 * (5 - $_)) & 31];
-	}
-	return $checksum;
-}
-
 sub verify_checksum
 {
 	my ($hrp, $data) = @_;
 	return polymod([@{hrp_expand $hrp}, @{to_numarr $data}]) == 1;
 }
 
-sub verify_checksum_bech32m
-{
-	my ($hrp, $data) = @_;
-	return polymod([@{hrp_expand $hrp}, @{to_numarr $data}]) == $BECH32M_CONSTANT;
-}
-
 sub split_bech32
 {
 	my ($bech32enc) = @_;
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'bech32 input is not a string'
+		"bech32 input is not a string"
 	) unless Str->check($bech32enc);
 
 	$bech32enc = lc $bech32enc
 		if uc $bech32enc eq $bech32enc;
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'bech32 string too long'
+		"bech32 string too long"
 	) if length $bech32enc > 90;
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'bech32 string contains mixed case'
+		"bech32 string contains mixed case"
 	) if lc $bech32enc ne $bech32enc;
 
-	my @parts = split /1/, $bech32enc;
+	my @parts = split "1", $bech32enc;
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'bech32 separator character missing'
+		"bech32 separator character missing"
 	) if @parts < 2;
 
 	my $data = pop @parts;
 
-	@parts = (join('1', @parts), $data);
+	@parts = (join("1", @parts), $data);
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'incorrect length of bech32 human readable part'
+		"incorrect length of bech32 human readable part"
 	) if length $parts[0] < 1 || length $parts[0] > 83;
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'illegal characters in bech32 human readable part'
+		"illegal characters in bech32 human readable part"
 	) if $parts[0] !~ /^[\x21-\x7e]+$/;
 
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'incorrect length of bech32 data part'
+		"incorrect length of bech32 data part"
 	) if length $parts[1] < 6;
 
-	my $chars = join '', @alphabet;
+	my $chars = join "", @alphabet;
 	Bitcoin::Crypto::Exception::Bech32InputFormat->raise(
-		'illegal characters in bech32 data part'
+		"illegal characters in bech32 data part"
 	) if $parts[1] !~ /^[$chars]+$/;
 
+	Bitcoin::Crypto::Exception::Bech32InputChecksum->raise(
+		"incorrect bech32 checksum"
+	) unless verify_checksum(@parts);
+
 	return @parts;
 }
 
-# used during segwit address decoding
-sub translate_5to8
-{
-	my ($values_ref) = @_;
-	my @enc_values = @{$values_ref};
-
-	my $bits = unpack 'B*', pack 'C*', @enc_values;
-	$bits = join '', map { substr $_, 3 } unpack '(a8)*', $bits;
-
-	my $length_padded = length $bits;
-	my $padding = $length_padded % 8;
-	$bits =~ s/0{$padding}$//;
-
-	Bitcoin::Crypto::Exception::Bech32InputData->raise(
-		'incorrect padding encoded in bech32'
-	) if length($bits) % 8 != 0 || length($bits) < $length_padded - 4;
-
-	my @data = unpack '(a8)*', $bits;
-	my $result = '';
-	for my $bitstr (@data) {
-		$result .= pack 'B8', $bitstr;
-	}
-	return $result;
-}
-
-# used during segwit address encoding
-sub translate_8to5
-{
-	my ($bytes) = @_;
-	verify_bytestring($bytes);
-
-	my @data = unpack '(a5)*', unpack 'B*', $bytes;
-	my @result;
-	for my $bitstr (@data) {
-		my $pad = 5 - length $bitstr;
-		my $num = unpack 'C', pack 'B*', "000$bitstr" . 0 x $pad;
-		push @result, $num;
-	}
-
-	return \@result;
-}
-
 sub encode_base32
 {
-	my ($array) = @_;
+	my ($bytes) = @_;
 
-	my $result = '';
-	for my $num (@{$array}) {
-		Bitcoin::Crypto::Exception::Bech32InputData->raise(
-			'incorrect number to be encoded in bech32: must be between 0 and 31'
-		) if $num < 0 || $num > 31;
+	my @data = unpack "(a5)*", unpack "B*", $bytes;
+	my $result = "";
+	for my $bitstr (@data) {
+		my $pad = 5 - length $bitstr;
+		my $num = unpack "C", pack "B*", "000$bitstr" . 0 x $pad;
 		$result .= $alphabet[$num];
 	}
 
@@ -215,31 +155,35 @@ sub decode_base32
 {
 	my ($encoded) = @_;
 
-	my @enc_values = map { $alphabet_mapped{$_} } split //, $encoded;
+	return ""
+		unless length $encoded;
+	my @enc_values = map { $alphabet_mapped{$_} } split "", $encoded;
+	my $bits = unpack "B*", pack "C*", @enc_values;
+	$bits = join "", map { substr $_, 3 } unpack "(a8)*", $bits;
 
-	return \@enc_values;
+	my $length_padded = length $bits;
+	my $padding = $length_padded % 8;
+	$bits =~ s/0{$padding}$//;
+
+	Bitcoin::Crypto::Exception::Bech32InputData->raise(
+		"incorrect padding encoded in bech32"
+	) if length($bits) % 8 != 0 || length($bits) < $length_padded - 4;
+
+	my @data = unpack "(a8)*", $bits;
+	my $result = "";
+	for my $bitstr (@data) {
+		$result .= pack "B8", $bitstr;
+	}
+	return $result;
 }
 
 sub encode_bech32
 {
-	my ($hrp, $data, $type) = @_;
-	$type //= BECH32M;
-
-	my $result = encode_base32($data);
-	my $checksum;
-
-	if ($type eq BECH32) {
-		$checksum = create_checksum($hrp, $result);
-	}
-	elsif ($type eq BECH32M) {
-		$checksum = create_checksum_bech32m($hrp, $result);
-	}
-	else {
-		Bitcoin::Crypto::Exception::Bech32Type->raise(
-			'invalid type: neither bech32 nor bech32m'
-		);
-	}
+	my ($hrp, $bytes) = @_;
+	verify_bytestring($bytes);
 
+	my $result = encode_base32($bytes);
+	my $checksum = create_checksum($hrp, $result);
 	return $hrp . 1 . $result . $checksum;
 }
 
@@ -248,37 +192,24 @@ sub encode_segwit
 	my ($hrp, $bytes) = @_;
 
 	my $version = validate_program($bytes);
-	return encode_bech32($hrp, [$version, @{translate_8to5(substr $bytes, 1)}], $version == 0 ? BECH32 : BECH32M);
+	my $result = $alphabet[$version] . encode_base32(substr $bytes, 1);
+	my $checksum = create_checksum($hrp, $result);
+	return $hrp . 1 . $result . $checksum;
 }
 
 sub decode_bech32
 {
 	my ($hrp, $data) = split_bech32 @_;
 
-	my $type;
-	$type = BECH32
-		if verify_checksum($hrp, $data);
-	$type = BECH32M
-		if !$type && verify_checksum_bech32m($hrp, $data);
-
-	Bitcoin::Crypto::Exception::Bech32InputChecksum->raise(
-		'incorrect bech32 checksum'
-	) unless $type;
-
-	return ($hrp, decode_base32(substr $data, 0, -$CHECKSUM_SIZE), $type);
+	return decode_base32(substr $data, 0, -$CHECKSUM_SIZE);
 }
 
 sub decode_segwit
 {
-	my ($hrp, $data, $type) = decode_bech32 @_;
-	my $ver = shift @{$data};
+	my ($hrp, $data) = split_bech32 @_;
 
-	Bitcoin::Crypto::Exception::Bech32InputChecksum->raise(
-		'wrong bech32 checksum calculated for given segwit program'
-	) if ($ver == 0 && $type ne BECH32)
-		|| ($ver > 0 && $type ne BECH32M);
-
-	my $bytes = pack('C', $ver) . translate_5to8 $data;
+	my $ver = $alphabet_mapped{substr $data, 0, 1};
+	my $bytes = pack("C", $ver) . decode_base32(substr $data, 1, -$CHECKSUM_SIZE);
 	validate_program($bytes);
 
 	return $bytes;
@@ -295,16 +226,15 @@ Bitcoin::Crypto::Bech32 - Bitcoin's Bech32 implementation in Perl
 
 	# none exported by default
 	use Bitcoin::Crypto::Bech32 qw(
-		translate_5to8
-		translate_8to5
 		encode_bech32
 		decode_bech32
+		split_bech32
 		encode_segwit
 		decode_segwit
 	);
 
 	# witness version - a number from 0 to 16, packed into a byte
-	my $version = pack 'C', 0;
+	my $version = pack "C", 0;
 
 	# human readable part of the address - a string
 	my $network_hrp = Bitcoin::Crypto::Network->get->segwit_hrp;
@@ -314,18 +244,18 @@ Bitcoin::Crypto::Bech32 - Bitcoin's Bech32 implementation in Perl
 	my $data_with_version = decode_segwit($segwit_address);
 
 	# handles custom Bech32 encoding
-	my $bech32str = encode_bech32('hello', [28, 25, 31, 0, 5], Bitcoin::Crypto::Bech32->BECH32); # should start with hello1
-	my ($hrp, $data_aref, $type) = decode_bech32($bech32str);
+	my $bech32str = encode_bech32("hello", pack "A*", "world"); # should start with hello1
+	my $bytestr = decode_bech32($bech32str);
 
 =head1 DESCRIPTION
 
-Implementation of Bech32 algorithm (BIP-173 and BIP-350 compatible)
+Implementation of Bech32 algorithm (BIP173 compatible)
 
 The module has a couple of layers of encoding, namely:
 
 =over
 
-=item * 5-to-8 and 8-to-5 bits transformation
+=item * base32, which handles the alphabet and 5-to-8 transformation (not exported)
 
 =item * bech32, which handles checksums and human-readable (HRP) parts
 
@@ -345,62 +275,33 @@ This module is based on Exporter. None of the functions are exported by default.
 
 =head2 encode_segwit
 
-	my $encoded_address = encode_segwit($hrp, $segwit_program);
-
 =head2 decode_segwit
 
-	my $segwit_program = decode_segwit($encoded_address);
-
 Bech32 encoding / decoding valid for SegWit addresses. Does not validate the human readable part.
 
 These functions also perform segwit program validation, see L<Bitcoin::Crypto::Segwit>.
 
-Encoding takes two arguments which are a human readable part and a bytestring.
+Encoding takes two arguments which are a human readable part and a byte string.
 
-Decoding takes bech32-encoded string. Returns the entire encoded data (bytestring) along with the segwit program version byte.
+Decoding takes bech32-encoded string. Returns the entire encoded data along with the segwit program version byte.
 
 =head2 encode_bech32
 
-	my $encoded_bech32 = encode_bech32($hrp, \@data, Bitcoin::Crypto::Bech32->BECH32 || Bitcoin::Crypto::Bech32->BECH32M);
-
 =head2 decode_bech32
 
-	my ($hrp, $data_aref, $type) = decode_bech32($encoded_bech32);
-
 Basic bech32 encoding / decoding.
 
-Encoding takes up to three arguments which are:
+Encoding takes two arguments which are a human readable part and a byte string.
 
-=over
-
-=item * a human readable part
-
-=item * an array reference of integer values to be encoded in bech32 (each must be between 0 and 31)
-
-=item * optional type, which may be C<'bech32'> or C<'bech32m'> (available in constant values Bitcoin::Crypto::Bech32::BECH32 and Bitcoin::Crypto::Bech32::BECH32M)
-
-If omitted, the type will be equal to C<'bech32m'>, which has more robust checksum.
-
-=back
-
-Decoding takes a single parameter: a bech32-encoded string and returns a list which has the same elements as arguments to C<encode_bech32> function.
-
-This means you can feed both bech32 and bech32m encodings to C<decode_bech32> and the function will identify and return the type for you.
+Decoding takes bech32-encoded string.
 
 B<These methods are not meant to work with Bitcoin SegWit addresses, use encode_segwit and decode_segwit for that instead>
 
-=head2 translate_5to8
+=head2 split_bech32
 
-	my $bytestr = translate_5to8(\@int_array);
+Splits a bech32-encoded string into human-readable part and data part. Returns a list containing the two.
 
-=head2 translate_8to5
-
-	my $int_aref = translate_8to5($bytestr);
-
-These are helper functions that implement 5-bit to 8-bit encoding used in bech32 segwit addresses. C<translate_8to5> is used during encoding, and C<translate_5to8> during decoding. They can be used as means to store full byte data in bech32 strings, like so:
-
-	my $data = encode_bech32('hrp', translate_8to5($bytes));
-	my $decoded = translate_5to8(decode_bech32($data));
+Performs all validity checks on the input. Dies on every error.
 
 =head1 EXCEPTIONS
 
@@ -414,8 +315,6 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 
 =item * Bech32InputChecksum - checksum validation has failed
 
-=item * Bech32Type - invalid type was passed to bech32_encode function
-
 =back
 
 =head1 SEE ALSO
@@ -431,4 +330,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
