@@ -1,13 +1,11 @@
 package Bitcoin::Crypto::Exception;
-$Bitcoin::Crypto::Exception::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
-use Mooish::AttributeBuilder -standard;
-
-use Bitcoin::Crypto::Types qw(Str Maybe ArrayRef);
+use Types::Standard qw(Maybe Str ArrayRef);
 
 use namespace::clean;
 
@@ -15,11 +13,14 @@ use overload
 	q{""} => "as_string",
 	fallback => 1;
 
-has param 'message' => (
+has 'message' => (
+	is => 'ro',
 	isa => Str,
+	required => 1,
 );
 
-has field 'caller' => (
+has 'caller' => (
+	is => 'ro',
 	isa => Maybe [ArrayRef],
 	default => sub {
 		for my $call_level (1 .. 10) {
@@ -30,6 +31,7 @@ has field 'caller' => (
 		}
 		return undef;
 	},
+	init_arg => undef,
 );
 
 sub raise
@@ -92,146 +94,98 @@ sub as_string
 {
 
 	package Bitcoin::Crypto::Exception::Sign;
-$Bitcoin::Crypto::Exception::Sign::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Sign::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Verify;
-$Bitcoin::Crypto::Exception::Verify::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Verify::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::KeyCreate;
-$Bitcoin::Crypto::Exception::KeyCreate::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::KeyCreate::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::KeyDerive;
-$Bitcoin::Crypto::Exception::KeyDerive::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::KeyDerive::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::MnemonicGenerate;
-$Bitcoin::Crypto::Exception::MnemonicGenerate::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::MnemonicGenerate::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::MnemonicCheck;
-$Bitcoin::Crypto::Exception::MnemonicCheck::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::MnemonicCheck::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Base58InputFormat;
-$Bitcoin::Crypto::Exception::Base58InputFormat::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Base58InputFormat::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Base58InputChecksum;
-$Bitcoin::Crypto::Exception::Base58InputChecksum::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Base58InputChecksum::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32InputFormat;
-$Bitcoin::Crypto::Exception::Bech32InputFormat::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Bech32InputFormat::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32InputData;
-$Bitcoin::Crypto::Exception::Bech32InputData::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Bech32InputData::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
-}
-
-{
-
-	package Bitcoin::Crypto::Exception::Bech32Type;
-$Bitcoin::Crypto::Exception::Bech32Type::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Bech32Type::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::Bech32InputChecksum;
-$Bitcoin::Crypto::Exception::Bech32InputChecksum::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::Bech32InputChecksum::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::SegwitProgram;
-$Bitcoin::Crypto::Exception::SegwitProgram::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::SegwitProgram::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::ValidationTest;
-$Bitcoin::Crypto::Exception::ValidationTest::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::ValidationTest::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::ScriptOpcode;
-$Bitcoin::Crypto::Exception::ScriptOpcode::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::ScriptOpcode::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::ScriptPush;
-$Bitcoin::Crypto::Exception::ScriptPush::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::ScriptPush::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 {
 
 	package Bitcoin::Crypto::Exception::NetworkConfig;
-$Bitcoin::Crypto::Exception::NetworkConfig::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::NetworkConfig::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
-}
-
-{
-
-	package Bitcoin::Crypto::Exception::AddressGenerate;
-$Bitcoin::Crypto::Exception::AddressGenerate::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Exception::AddressGenerate::VERSION = '1.00801';
-use parent -norequire, 'Bitcoin::Crypto::Exception';
+	use parent -norequire, "Bitcoin::Crypto::Exception";
 }
 
 1;
@@ -246,7 +200,7 @@ Bitcoin::Crypto::Exception - Exception class for Bitcoin::Crypto purposes
 	use Try::Tiny;
 
 	try {
-		decode_segwit('Not a segwit address');
+		decode_segwit("Not a segwit address");
 	} catch {
 		my $error = $_;
 
@@ -254,7 +208,7 @@ Bitcoin::Crypto::Exception - Exception class for Bitcoin::Crypto purposes
 		warn "$error";
 
 		# but also contains some information about the problem to avoid regex matching
-		if ($error->isa('Bitcoin::Crypto::Exception::Bech32InputFormat')) {
+		if ($error->isa("Bitcoin::Crypto::Exception::Bech32InputFormat")) {
 			log $error->message;
 		}
 	};
@@ -296,7 +250,7 @@ Creates a new instance and throws it. If used on an object, throws it right away
 
 	try {
 		# throws, but will be catched
-		Bitcoin::Crypto::Exception->raise('something went wrong');
+		Bitcoin::Crypto::Exception->raise("something went wrong");
 	} catch {
 		my $exception = $_;
 
@@ -315,8 +269,7 @@ An alias to C<raise>.
 Executes the subroutine given as the only parameter inside an C<eval>. Any exceptions thrown inside the subroutine C<$sub> will be re-thrown after turning them into objects of the given class. If no exception is thrown, method returns the value returned by C<$sub>.
 
 	my $result = Bitcoin::Crypto::Exception->trap_into(sub {
-		die 'something went wrong';
+		die "something went wrong";
 	});
 
 =cut
-
