@@ -1,12 +1,13 @@
 package Bitcoin::Crypto::Key::ExtPrivate;
-$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
 use Crypt::Mac::HMAC qw(hmac);
 use Bitcoin::BIP39 qw(gen_bip39_mnemonic bip39_mnemonic_to_entropy entropy_to_bip39_mnemonic);
+use Scalar::Util qw(blessed);
 
 use Bitcoin::Crypto::BIP44;
 use Bitcoin::Crypto::Key::ExtPublic;
@@ -17,7 +18,7 @@ use Bitcoin::Crypto::Exception;
 
 use namespace::clean;
 
-with qw(Bitcoin::Crypto::Role::ExtendedKey);
+with "Bitcoin::Crypto::Role::ExtendedKey";
 
 sub _is_private { 1 }
 
@@ -26,7 +27,7 @@ sub generate_mnemonic
 	my ($class, $len, $lang) = @_;
 	my ($min_len, $len_div, $max_len) = (128, 32, 256);
 	$len //= $min_len;
-	$lang //= 'en';
+	$lang //= "en";
 
 	# bip39 specification values
 	Bitcoin::Crypto::Exception::MnemonicGenerate->raise(
@@ -44,7 +45,7 @@ sub generate_mnemonic
 sub mnemonic_from_entropy
 {
 	my ($class, $entropy, $lang) = @_;
-	$lang //= 'en';
+	$lang //= "en";
 
 	return Bitcoin::Crypto::Exception::MnemonicGenerate->trap_into(
 		sub {
@@ -82,21 +83,18 @@ sub from_seed
 	my ($class, $seed) = @_;
 	verify_bytestring($seed);
 
-	my $bytes = hmac('SHA512', 'Bitcoin seed', $seed);
+	my $bytes = hmac("SHA512", "Bitcoin seed", $seed);
 	my $key = substr $bytes, 0, 32;
 	my $cc = substr $bytes, 32, 32;
 
-	return $class->new(
-		key_instance => $key,
-		chain_code => $cc,
-	);
+	return $class->new($key, $cc);
 }
 
 sub from_hex_seed
 {
 	my ($class, $seed) = @_;
 
-	return $class->from_seed(pack 'H*', pad_hex $seed);
+	return $class->from_seed(pack "H*", pad_hex $seed);
 }
 
 sub get_public_key
@@ -104,14 +102,13 @@ sub get_public_key
 	my ($self) = @_;
 
 	my $public = Bitcoin::Crypto::Key::ExtPublic->new(
-		key_instance => $self->raw_key('public'),
-		chain_code => $self->chain_code,
-		child_number => $self->child_number,
-		parent_fingerprint => $self->parent_fingerprint,
-		depth => $self->depth,
-		network => $self->network,
-		purpose => $self->purpose,
+		$self->raw_key("public"),
+		$self->chain_code,
+		$self->child_number,
+		$self->parent_fingerprint,
+		$self->depth
 	);
+	$public->set_network($self->network);
 
 	return $public;
 }
@@ -142,18 +139,18 @@ sub _derive_key_partial
 	}
 	else {
 		# public key data - SEC compressed form
-		$hmac_data .= $self->raw_key('public_compressed');
+		$hmac_data .= $self->raw_key("public_compressed");
 	}
 
 	# child number - 4 bytes
-	$hmac_data .= ensure_length pack('N', $child_num), 4;
+	$hmac_data .= ensure_length pack("N", $child_num), 4;
 
-	my $data = hmac('SHA512', $self->chain_code, $hmac_data);
+	my $data = hmac("SHA512", $self->chain_code, $hmac_data);
 	my $chain_code = substr $data, 32, 32;
 
 	my $number = new_bigint(substr $data, 0, 32);
 	my $key_num = new_bigint($self->raw_key);
-	my $n_order = new_bigint(pack 'H*', $self->key_instance->curve2hash->{order});
+	my $n_order = new_bigint(pack "H*", $self->key_instance->curve2hash->{order});
 
 	Bitcoin::Crypto::Exception::KeyDerive->raise(
 		"key $child_num in sequence was found invalid"
@@ -166,12 +163,12 @@ sub _derive_key_partial
 		"key $child_num in sequence was found invalid"
 	) if $number->beq(0);
 
-	return $self->new(
-		key_instance => $number->as_bytes,
-		chain_code => $chain_code,
-		child_number => $child_num,
-		parent_fingerprint => $self->get_fingerprint,
-		depth => $self->depth + 1,
+	return (blessed $self)->new(
+		$number->as_bytes,
+		$chain_code,
+		$child_num,
+		$self->get_fingerprint,
+		$self->depth + 1
 	);
 }
 
@@ -225,15 +222,9 @@ see L<Bitcoin::Crypto::Network> if you want to work with other networks than Bit
 
 =head1 METHODS
 
-=head2 new
-
-Constructor is reserved for internal and advanced use only. Use
-L</from_mnemonic>, L</from_seed>, L</from_hex_seed>, L</from_serialized> and
-L</from_serialized_base58> instead.
-
 =head2 generate_mnemonic
 
-	$mnemonic = $class->generate_mnemonic($len = 128, $lang = 'en')
+	$mnemonic = $class->generate_mnemonic($len = 128, $lang = "en")
 
 Generates a new mnemonic code using L<Bytes::Random::Secure>. Default entropy is 128 bits.
 With C<$len> this can be changed to up to 256 bits with 32 bit step.
@@ -247,7 +238,7 @@ In some environments a problem may be encountered that causes the secure random
 
 =head2 mnemonic_from_entropy
 
-	$mnemonic = $class->mnemonic_from_entropy($bytes, $lang = 'en')
+	$mnemonic = $class->mnemonic_from_entropy($bytes, $lang = "en")
 
 Generates a new mnemonic code from custom entropy given in C<$bytes> (a bytestring). This entropy should be of the same bit size as in L</"generate_mnemonic">. Returns newly generated BIP39 mnemonic string.
 
@@ -259,13 +250,13 @@ Be aware that the method you use to generate a mnemonic will be a very important
 
 =head2 from_mnemonic
 
-	$key_object = $class->from_mnemonic($mnemonic, $password = '', $lang = undef)
+	$key_object = $class->from_mnemonic($mnemonic, $password = "", $lang = undef)
 
 Creates a new key from given mnemonic and password.
 
 Note that technically any password is correct and there's no way to tell if it was mistaken.
 
-If you need to validate if C<$mnemonic> is a valid mnemonic you should specify C<$lang>, e.g. 'en'.
+If you need to validate if C<$mnemonic> is a valid mnemonic you should specify C<$lang>, e.g. "en".
 
 If no C<$lang> is given then any string passed as C<$mnemonic> will produce a valid key.
 
@@ -347,8 +338,6 @@ Returns a new extended key instance - result of a derivation.
 
 A helper that constructs a L<Bitcoin::Crypto::BIP44> path from C<%data> and calls L</derive_key> with it. Refer to L<Bitcoin::Crypto::BIP44/PROPERTIES> to see what you can include in C<%data>.
 
-Using this method instead of specifying BIP44 path yourself will make sure all features of BIP44 derivation will be enabled, like different prefixes for extended keys (C<xprv> / C<yprv> / C<zprv>) and address type generation checking.
-
 I<Note: coin_type parameter will be ignored, and the current network configuration set in the extended key will be used.>
 
 =head2 get_fingerprint
@@ -386,4 +375,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
