@@ -1,11 +1,12 @@
 package Bitcoin::Crypto::Key::ExtPublic;
-$Bitcoin::Crypto::Key::ExtPublic::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Key::ExtPublic::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
 use Crypt::Mac::HMAC qw(hmac);
+use Scalar::Util qw(blessed);
 
 use Bitcoin::Crypto::Config;
 use Bitcoin::Crypto::Helpers qw(new_bigint ensure_length add_ec_points);
@@ -13,7 +14,7 @@ use Bitcoin::Crypto::Exception;
 
 use namespace::clean;
 
-with qw(Bitcoin::Crypto::Role::ExtendedKey);
+with "Bitcoin::Crypto::Role::ExtendedKey";
 
 sub _is_private { 0 }
 
@@ -22,39 +23,39 @@ sub _derive_key_partial
 	my ($self, $child_num, $hardened) = @_;
 
 	Bitcoin::Crypto::Exception::KeyDerive->raise(
-		'cannot derive hardened key from public key'
+		"cannot derive hardened key from public key"
 	) if $hardened;
 
 	# public key data - SEC compressed form
-	my $hmac_data = $self->raw_key('public_compressed');
+	my $hmac_data = $self->raw_key("public_compressed");
 
 	# child number - 4 bytes
-	$hmac_data .= ensure_length pack('N', $child_num), 4;
+	$hmac_data .= ensure_length pack("N", $child_num), 4;
 
-	my $data = hmac('SHA512', $self->chain_code, $hmac_data);
+	my $data = hmac("SHA512", $self->chain_code, $hmac_data);
 	my $chain_code = substr $data, 32, 32;
 
-	my $n_order = new_bigint(pack 'H*', $self->key_instance->curve2hash->{order});
+	my $n_order = new_bigint(pack "H*", $self->key_instance->curve2hash->{order});
 	my $number = new_bigint(substr $data, 0, 32);
 	Bitcoin::Crypto::Exception::KeyDerive->raise(
 		"key $child_num in sequence was found invalid"
 	) if $number->bge($n_order);
 
 	my $key = $self->_create_key(substr $data, 0, 32);
-	my $point = $key->export_key_raw('public');
-	my $parent_point = $self->raw_key('public');
+	my $point = $key->export_key_raw("public");
+	my $parent_point = $self->raw_key("public");
 	$point = add_ec_points($point, $parent_point);
 
 	Bitcoin::Crypto::Exception::KeyDerive->raise(
 		"key $child_num in sequence was found invalid"
 	) unless defined $point;
 
-	return $self->new(
-		key_instance => $point,
-		chain_code => $chain_code,
-		child_number => $child_num,
-		parent_fingerprint => $self->get_fingerprint,
-		depth => $self->depth + 1,
+	return (blessed $self)->new(
+		$point,
+		$chain_code,
+		$child_num,
+		$self->get_fingerprint,
+		$self->depth + 1
 	);
 }
 
@@ -99,11 +100,6 @@ see L<Bitcoin::Crypto::Network> if you want to work with other networks than Bit
 
 =head1 METHODS
 
-=head2 new
-
-Constructor is reserved for internal and advanced use only. Use L</from_serialized> and
-L</from_serialized_base58> instead.
-
 =head2 to_serialized
 
 	$serialized_key = $object->to_serialized()
@@ -187,4 +183,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
