@@ -1,10 +1,11 @@
 package Bitcoin::Crypto::Key::Private;
-$Bitcoin::Crypto::Key::Private::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Key::Private::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
+use Types::Standard qw(Str);
 use Crypt::PK::ECC;
 use Bitcoin::BIP39 qw(bip39_mnemonic_to_entropy entropy_to_bip39_mnemonic);
 use List::Util qw(first);
@@ -19,7 +20,7 @@ use Bitcoin::Crypto::Exception;
 
 use namespace::clean;
 
-with qw(Bitcoin::Crypto::Role::BasicKey);
+with "Bitcoin::Crypto::Role::BasicKey";
 
 sub _is_private { 1 }
 
@@ -45,7 +46,7 @@ sub from_wif
 	my ($class, $wif, $network) = @_;
 
 	Bitcoin::Crypto::Exception::KeyCreate->raise(
-		'base58 string is not valid WIF'
+		"base58 string is not valid WIF"
 	) unless validate_wif($wif);
 
 	my $decoded = decode_base58check($wif);
@@ -65,7 +66,7 @@ sub from_wif
 		if defined $network;
 
 	Bitcoin::Crypto::Exception::KeyCreate->raise(
-		'found multiple networks possible for given WIF'
+		"found multiple networks possible for given WIF"
 	) if @found_networks > 1;
 
 	Bitcoin::Crypto::Exception::KeyCreate->raise(
@@ -86,13 +87,9 @@ sub get_public_key
 {
 	my ($self) = @_;
 
-	my $public = Bitcoin::Crypto::Key::Public->new(
-		key_instance => $self->raw_key('public'),
-		compressed => $self->compressed,
-		network => $self->network,
-		purpose => $self->purpose,
-	);
-
+	my $public = Bitcoin::Crypto::Key::Public->new($self->raw_key("public"));
+	$public->set_compressed($self->compressed);
+	$public->set_network($self->network);
 	return $public;
 }
 
@@ -113,16 +110,16 @@ Bitcoin::Crypto::Key::Private - Bitcoin private keys
 
 	# create signature using private key (sha256 of string byte representation)
 
-	my $sig = $priv->sign_message('Hello world');
+	my $sig = $priv->sign_message("Hello world");
 
 	# signature is returned as byte string
 	# use unpack to get the representation you need
 
-	my $sig_hex = unpack 'H*', $sig;
+	my $sig_hex = unpack "H*", $sig;
 
 	# signature verification
 
-	$priv->verify_message('Hello world', $sig);
+	$priv->verify_message("Hello world", $sig);
 
 =head1 DESCRIPTION
 
@@ -144,11 +141,6 @@ see L<Bitcoin::Crypto::Network> if you want to work with other networks than Bit
 
 =head1 METHODS
 
-=head2 new
-
-Constructor is reserved for internal and advanced use only. Use L</from_bytes>,
-L</from_hex> and L</from_wif> instead.
-
 =head2 from_bytes
 
 	$key_object = $class->from_bytes($data)
@@ -158,6 +150,12 @@ Data C<$data> will be used as a private key entropy.
 
 Returns class instance.
 
+=head2 new
+
+	$key_object = $class->new($data)
+
+This works exactly the same as from_bytes
+
 =head2 to_bytes
 
 	$bytestring = $object->to_bytes()
@@ -219,11 +217,11 @@ Returns current key instance.
 
 	$public_key_object = $object->get_public_key()
 
-Returns instance of L<Bitcoin::Crypto::Key::Public> generated from the private key.
+Returns instance of L<Bitcoin::Crypto::PublicKey> generated from the private key.
 
 =head2 sign_message
 
-	$signature = $object->sign_message($message, $algo = 'sha256')
+	$signature = $object->sign_message($message, $algo = "sha256")
 
 Signs a digest of C<$message> (using C<$algo> digest algorithm) with a private key.
 
@@ -240,7 +238,7 @@ Caution: libtomcrypt cryptographic package that is generating signatures does no
 
 =head2 verify_message
 
-	$signature_valid = $object->verify_message($message, $signature, $algo = 'sha256')
+	$signature_valid = $object->verify_message($message, $signature, $algo = "sha256")
 
 Verifies C<$signature> against digest of C<$message> (with C<$algo> digest algorithm) using private key.
 
@@ -280,4 +278,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
