@@ -1,8 +1,8 @@
 package Bitcoin::Crypto::Key::Public;
-$Bitcoin::Crypto::Key::Public::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Key::Public::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
 
@@ -14,7 +14,7 @@ use Bitcoin::Crypto::Helpers qw(hash160);
 
 use namespace::clean;
 
-with qw(Bitcoin::Crypto::Role::BasicKey);
+with "Bitcoin::Crypto::Role::BasicKey";
 
 sub _is_private { 0 }
 
@@ -29,17 +29,12 @@ sub witness_program
 {
 	my ($self) = @_;
 
-	return pack('C', Bitcoin::Crypto::Config::witness_version) . $self->key_hash;
+	return pack("C", Bitcoin::Crypto::Config::witness_version) . $self->key_hash;
 }
 
 sub get_legacy_address
 {
 	my ($self) = @_;
-
-	Bitcoin::Crypto::Exception::AddressGenerate->raise(
-		'legacy addresses can only be created with BIP44 in legacy (BIP44) mode'
-	) unless $self->has_purpose(44);
-
 	my $pkh = $self->network->p2pkh_byte . $self->key_hash;
 	return encode_base58check($pkh);
 }
@@ -48,17 +43,8 @@ sub get_compat_address
 {
 	my ($self) = @_;
 
-	# network field is not required, lazy check for completeness
-	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		'this network does not support segregated witness'
-	) unless $self->network->supports_segwit;
-
-	Bitcoin::Crypto::Exception::AddressGenerate->raise(
-		'compat addresses can only be created with BIP44 in compat (BIP49) mode'
-	) unless $self->has_purpose(49);
-
 	my $program = Bitcoin::Crypto::Script->new(network => $self->network);
-	$program->add_operation('OP_' . Bitcoin::Crypto::Config::witness_version)
+	$program->add_operation("OP_" . Bitcoin::Crypto::Config::witness_version)
 		->push_bytes($self->key_hash);
 	return $program->get_legacy_address;
 }
@@ -69,12 +55,8 @@ sub get_segwit_address
 
 	# network field is not required, lazy check for completeness
 	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		'this network does not support segregated witness'
-	) unless $self->network->supports_segwit;
-
-	Bitcoin::Crypto::Exception::AddressGenerate->raise(
-		'segwit addresses can only be created with BIP44 in segwit (BIP84) mode'
-	) unless $self->has_purpose(84);
+		"no segwit_hrp found in network configuration"
+	) unless defined $self->network->segwit_hrp;
 
 	return encode_segwit($self->network->segwit_hrp, $self->witness_program);
 }
@@ -94,7 +76,7 @@ Bitcoin::Crypto::Key::Public - Bitcoin public keys
 
 	# verify signature (it has to be byte string, see perlpacktut)
 
-	$pub->verify_message(pack('a*', 'Hello world'), $sig);
+	$pub->verify_message(pack("a*", "Hello world"), $sig);
 
 	# getting address from public key (p2wpkh)
 
@@ -116,11 +98,6 @@ You can use a public key to:
 
 =head1 METHODS
 
-=head2 new
-
-Constructor is reserved for internal and advanced use only. Use L</from_bytes> and
-L</from_hex> instead.
-
 =head2 from_bytes
 
 	$key_object = $class->from_bytes($data)
@@ -130,6 +107,12 @@ Data C<$data> must represent a public key in ASN X9.62 format.
 
 Returns class instance.
 
+=head2 new
+
+	$key_object = $class->new($data)
+
+This works exactly the same as from_bytes
+
 =head2 to_bytes
 
 	$bytestring = $object->to_bytes()
@@ -169,7 +152,7 @@ Returns current key instance.
 
 =head2 verify_message
 
-	$signature_valid = $object->verify_message($message, $signature, $algo = 'sha256')
+	$signature_valid = $object->verify_message($message, $signature, $algo = "sha256")
 
 Verifies C<$signature> against digest of C<$message> (with C<$algo> digest algorithm) using public key.
 
@@ -186,10 +169,7 @@ Character encoding note: C<$message> should be encoded in the proper encoding be
 
 	$address_string = $object->get_legacy_address()
 
-Returns string containing Base58Check encoded public key hash (p2pkh address).
-
-If the public key was obtained through BIP44 derivation scheme, this method will check whether the purpose was C<44> and raise an exception otherwise.
-If you wish to generate this address anyway, call L</clear_purpose>.
+Returns string containing Base58Check encoded public key hash (p2pkh address)
 
 =head2 get_compat_address
 
@@ -197,24 +177,12 @@ If you wish to generate this address anyway, call L</clear_purpose>.
 
 Returns string containing Base58Check encoded script hash containing a witness program for compatibility purposes (p2sh(p2wpkh) address)
 
-If the public key was obtained through BIP44 derivation scheme, this method will check whether the purpose was C<49> and raise an exception otherwise.
-If you wish to generate this address anyway, call L</clear_purpose>.
-
 =head2 get_segwit_address
 
 	$address_string = $object->get_segwit_address()
 
 Returns string containing Bech32 encoded witness program (p2wpkh address)
 
-If the public key was obtained through BIP44 derivation scheme, this method will check whether the purpose was C<84> and raise an exception otherwise.
-If you wish to generate this address anyway, call L</clear_purpose>.
-
-=head2 clear_purpose
-
-	$object->clear_purpose;
-
-Clears the purpose of this key instance, removing safety checks on address generation.
-
 =head1 EXCEPTIONS
 
 This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters an error. It can produce the following error types from the L<Bitcoin::Crypto::Exception> namespace:
@@ -227,8 +195,6 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 
 =item * NetworkConfig - incomplete or corrupted network configuration
 
-=item * AddressGenerate - address could not be generated (see BIP44 constraint notes)
-
 =back
 
 =head1 SEE ALSO
@@ -246,4 +212,3 @@ This module throws an instance of L<Bitcoin::Crypto::Exception> if it encounters
 =back
 
 =cut
-
