@@ -1,78 +1,71 @@
 package Bitcoin::Crypto::Network;
-$Bitcoin::Crypto::Network::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Network::VERSION = '1.00801';
+
+our $VERSION = "1.001";
+
 use v5.10;
-use strict;
 use warnings;
 use Moo;
 use Scalar::Util qw(blessed);
-use Mooish::AttributeBuilder -standard;
+use Types::Standard qw(Str Int Str);
+use Types::Common::String qw(StrLength);
 
 use Bitcoin::Crypto::Exception;
-use Bitcoin::Crypto::Types qw(Str StrLength Int);
 
 use namespace::clean;
 
 my %networks;
 my $default_network;
 
-has param 'id' => (
+has "id" => (
+	is => "ro",
 	isa => Str,
+	required => 1,
 );
 
-has param 'name' => (
+has "name" => (
+	is => "ro",
 	isa => Str,
+	required => 1,
 );
 
-has param 'p2pkh_byte' => (
+has "p2pkh_byte" => (
+	is => "ro",
 	isa => StrLength [1, 1],
+	required => 1,
 );
 
-has param 'wif_byte' => (
+has "wif_byte" => (
+	is => "ro",
 	isa => StrLength [1, 1],
+	required => 1,
 );
 
-has param 'p2sh_byte' => (
+has "p2sh_byte" => (
+	is => "ro",
 	isa => StrLength [1, 1],
 	required => 0,
 );
 
-has param 'segwit_hrp' => (
+has "segwit_hrp" => (
+	is => "ro",
 	isa => Str,
 	required => 0,
 );
 
-has param 'extprv_version' => (
+has "extprv_version" => (
+	is => "ro",
 	isa => Int,
 	required => 0,
 );
 
-has param 'extpub_version' => (
+has "extpub_version" => (
+	is => "ro",
 	isa => Int,
 	required => 0,
 );
 
-has param 'extprv_compat_version' => (
-	isa => Int,
-	required => 0,
-);
-
-has param 'extpub_compat_version' => (
-	isa => Int,
-	required => 0,
-);
-
-has param 'extprv_segwit_version' => (
-	isa => Int,
-	required => 0,
-);
-
-has param 'extpub_segwit_version' => (
-	isa => Int,
-	required => 0,
-);
-
-has param 'bip44_coin' => (
+has "bip44_coin" => (
+	is => "ro",
 	isa => Int,
 	required => 0,
 );
@@ -92,24 +85,17 @@ sub set_default
 	my ($self) = @_;
 
 	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		'network must be an instance of Bitcoin::Crypto::Network'
+		"network must be an instance of Bitcoin::Crypto::Network"
 	) unless blessed($self);
 
 	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		'the network needs to be registered before becoming the default one'
+		"the network needs to be registered before becoming the default one"
 	) unless defined $networks{$self->id};
 
 	$default_network = $self->id;
 	return $self;
 }
 
-sub supports_segwit
-{
-	my ($self) = @_;
-
-	return defined $self->segwit_hrp;
-}
-
 sub find
 {
 	my ($class, $sub) = @_;
@@ -118,8 +104,8 @@ sub find
 		unless defined $sub;
 
 	Bitcoin::Crypto::Exception::NetworkConfig->raise(
-		'argument passed to Bitcoin::Crypto::Network->find must be a coderef returning boolean'
-	) unless ref $sub eq 'CODE';
+		"argument passed to Bitcoin::Crypto::Network->find must be a coderef returning boolean"
+	) unless ref $sub eq "CODE";
 
 	return grep { $sub->($networks{$_}) } keys %networks;
 }
@@ -136,80 +122,27 @@ sub get
 	return $network;
 }
 
-### PREDEFINED NETWORKS SECTION
-# When adding a network, make sure to:
-# - code in valid constants of the network below
-# - provide resources that will confirm these constant values (in the merge request)
-# - add your network to the POD documentation below
-# - add your network to test file 17-predefined-networks.t
-
-### BITCOIN
-
 __PACKAGE__->register(
-	id => 'bitcoin',
-	name => 'Bitcoin Mainnet',
+	id => "bitcoin",
+	name => "Bitcoin Mainnet",
 	p2pkh_byte => "\x00",
 	p2sh_byte => "\x05",
+	segwit_hrp => "bc",
 	wif_byte => "\x80",
-	segwit_hrp => 'bc',
-
 	extprv_version => 0x0488ade4,
 	extpub_version => 0x0488b21e,
-
-	extprv_compat_version => 0x049d7878,
-	extpub_compat_version => 0x049d7cb2,
-
-	extprv_segwit_version => 0x04b2430c,
-	extpub_segwit_version => 0x04b24746,
-
 	bip44_coin => 0,
 )->set_default;
 
 __PACKAGE__->register(
-	id => 'bitcoin_testnet',
-	name => 'Bitcoin Testnet',
+	id => "bitcoin_testnet",
+	name => "Bitcoin Testnet",
 	p2pkh_byte => "\x6f",
 	p2sh_byte => "\xc4",
+	segwit_hrp => "tb",
 	wif_byte => "\xef",
-	segwit_hrp => 'tb',
-
 	extprv_version => 0x04358394,
 	extpub_version => 0x043587cf,
-
-	extprv_compat_version => 0x044a4e28,
-	extpub_compat_version => 0x044a5262,
-
-	extprv_segwit_version => 0x045f18bc,
-	extpub_segwit_version => 0x045f1cf6,
-
-	bip44_coin => 1,
-);
-
-### DOGECOIN
-
-__PACKAGE__->register(
-	id => 'dogecoin',
-	name => 'Dogecoin Mainnet',
-	p2pkh_byte => "\x1e",
-	p2sh_byte => "\x16",
-	wif_byte => "\x9e",
-
-	extprv_version => 0x02fac398,
-	extpub_version => 0x02facafd,
-
-	bip44_coin => 3,
-);
-
-__PACKAGE__->register(
-	id => 'dogecoin_testnet',
-	name => 'Dogecoin Testnet',
-	p2pkh_byte => "\x71",
-	p2sh_byte => "\xc4",
-	wif_byte => "\xf1",
-
-	extprv_version => 0x04358394,
-	extpub_version => 0x043587cf,
-
 	bip44_coin => 1,
 );
 
@@ -236,13 +169,13 @@ Bitcoin::Crypto::Network - Management tool for cryptocurrency networks
 
 	# you can get full network configuration with get() using network id
 
-	Bitcoin::Crypto::Network->get('bitcoin_testnet')->name; # Bitcoin Testnet
+	Bitcoin::Crypto::Network->get("bitcoin_testnet")->name; # Bitcoin Testnet
 
 	# search for network and get array of keys in return
 	# there will be multiple results if your search is matched
 	# by multiple networks
 
-	Bitcoin::Crypto::Network->find(sub { shift->name eq 'Bitcoin Mainnet' }); # (mainnet)
+	Bitcoin::Crypto::Network->find(sub { shift->name eq "Bitcoin Mainnet" }); # (mainnet)
 	Bitcoin::Crypto::Network->find(sub { shift->p2pkh_byte eq "\x6f" }); # (testnet)
 
 	# if you're working with cryptocurrency other than Bitcoin you need to add a new network
@@ -254,8 +187,8 @@ Bitcoin::Crypto::Network - Management tool for cryptocurrency networks
 	# register() can be used to create a network
 
 	my $litecoin = Bitcoin::Crypto::Network->register(
-		id => 'litecoin',
-		name => 'Litecoin Mainnet',
+		id => "litecoin",
+		name => "Litecoin Mainnet",
 		p2pkh_byte => "\x30",
 		wif_byte => "\xb0",
 	);
@@ -272,35 +205,31 @@ Bitcoin::Crypto::Network - Management tool for cryptocurrency networks
 
 This package allows you to manage non-bitcoin cryptocurrencies.
 Before you start producing keys and addresses for your favorite crypto
-you have to configure its network first.
+you have to configure it's network first.
 
 =head1 PREDEFINED NETWORKS
 
-Here is a list of networks that are already defined and can be used without defining them.
+There are a couple of networks that are already defined and can be used without defining them:
+
+=over
+
+=item * Bitcoin Mainnet
+
+defined with id: C<bitcoin>
+
+=item * Bitcoin Testnet
+
+defined with id: C<bitcoin_testnet>
+
+=back
 
 If you want to see more predefined networks added and you're willing to make
 some research to find out the correct values for the configuration fields,
 consider opening a pull request on Github.
 
-=head2 Bitcoin Mainnet
-
-defined with id: C<bitcoin>
-
-=head2 Bitcoin Testnet
-
-defined with id: C<bitcoin_testnet>
-
-=head2 Dogecoin Mainnet
-
-defined with id: C<dogecoin>
-
-=head2 Dogecoin Testnet
-
-defined with id: C<dogecoin_testnet>
-
 =head1 CONFIGURATION
 
-Right now networks only require four keys, which are marked with C<(*)>
+Right now networks only require four keys, which are marked with (*)
 
 	my %config = (
 		id             => "(*) identifier for the network",
@@ -309,15 +238,9 @@ Right now networks only require four keys, which are marked with C<(*)>
 		wif_byte       => "(*) WIF private key prefix byte, eg. 0x80",
 		p2sh_byte      => "p2sh address prefix byte, eg. 0x05",
 		segwit_hrp     => "segwit native address human readable part, eg. 'bc'",
-
-		extprv_version        => "version prefix of serialized extended private keys, eg. 0x0488ade4",
-		extpub_version        => "version prefix of serialized extended public keys, eg. 0x0488b21e",
-		extprv_compat_version => "same as extprv_version, but for BIP49",
-		extpub_compat_version => "same as extpub_version, but for BIP49",
-		extprv_segwit_version => "same as extprv_version, but for BIP84",
-		extpub_segwit_version => "same as extpub_version, but for BIP84",
-
-		bip44_coin => "bip44 coin number, eg. 0",
+		extprv_version => "version of extended private keys, eg. 0x0488ade4",
+		extpub_version => "version of extended public keys, eg. 0x0488b21e",
+		bip44_coin     => "bip44 coin number, eg. 0",
 	);
 
 After you register a network with this hashref your program will be able to import keys for that
@@ -325,7 +248,7 @@ network but all keys created from other sources will be treated as Bitcoin.
 You need to set_default to make all new keys use it. If you use many
 networks it might be better to set a network with key's set_network method:
 
-	$priv->set_network('network_id');
+	$priv->set_network("network_id");
 
 Remember that if you don't specify network field for some feature you won't be able to
 use it. For example the module will complain if you try to generate segwit address
@@ -352,12 +275,6 @@ Sets the network as default one. All newly created private and public keys will
 
 Returns the network instance.
 
-=head2 supports_segwit
-
-	$bool = $object->supports_segwit()
-
-Returns a boolean which can be used to determine whether a given network has segwit configured.
-
 =head2 new
 
 	$network_object = $class->new(%config)
@@ -391,7 +308,7 @@ test will be returned. Example:
 
 	sub {
 		my $instance = shift;
-		return $instance->name eq 'Some name';
+		return $instance->name eq "Some name";
 	}
 
 =head1 SEE ALSO
@@ -405,4 +322,3 @@ test will be returned. Example:
 =back
 
 =cut
-
