@@ -1,19 +1,20 @@
 package Bitcoin::Crypto::Role::Compressed;
-$Bitcoin::Crypto::Role::Compressed::VERSION = '1.008_01'; # TRIAL
-$Bitcoin::Crypto::Role::Compressed::VERSION = '1.00801';
-use v5.10;
-use strict;
-use warnings;
-use Mooish::AttributeBuilder -standard;
 
-use Bitcoin::Crypto::Types qw(Bool);
+our $VERSION = "1.001";
+
+use v5.10;
+use warnings;
+use Types::Standard qw(Bool);
+
 use Bitcoin::Crypto::Config;
 use Moo::Role;
 
-has param 'compressed' => (
-	coerce => Bool,
+has "compressed" => (
+	is => "rw",
+	isa => Bool,
+	coerce => 1,
 	default => Bitcoin::Crypto::Config::compress_public_point,
-	writer => -hidden,
+	writer => "_set_compressed"
 );
 
 sub set_compressed
@@ -28,4 +29,3 @@ sub set_compressed
 }
 
 1;
-
